"use client";

import { z } from "zod";
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from "@/components/ui/form";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion";
import { useForm } from "react-hook-form";
import { toast } from "@/hooks/use-toast";
import { Input } from "@/components/ui/input";
import { zodResolver } from "@hookform/resolvers/zod";

const basicFormSchema = z.object({
  title: z.string().min(1, { message: "题目标题不能为空" }),
  difficulty: z.enum(["简单", "中等", "困难"], {
    required_error: "请选择题目难度",
  }),
});

type BasicFormValues = z.infer<typeof basicFormSchema>;

export function BasicForm() {
  const form = useForm<BasicFormValues>({
    resolver: zodResolver(basicFormSchema),
    defaultValues: {
      title: "",
      difficulty: undefined,
    },
  });

  function onSubmit(data: BasicFormValues) {
    toast({
      title: "题目基本信息创建成功",
      description: (
        <div>
          <p>题目标题：{data.title}</p>
          <p>题目难度：{data.difficulty}</p>
        </div>
      ),
    });
  }

  return (
    <Form {...form}>
      <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
        <FormField
          control={form.control}
          name="title"
          render={({ field }) => (
            <FormItem>
              <FormLabel>题目标题</FormLabel>
              <FormControl>
                <Input {...field} placeholder="例如： 两数之和" />
              </FormControl>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="difficulty"
          render={({ field }) => (
            <FormItem>
              <FormLabel>题目难度</FormLabel>
              <Select onValueChange={field.onChange} defaultValue={field.value}>
                <FormControl>
                  <SelectTrigger>
                    <SelectValue placeholder="点击此处选择" />
                  </SelectTrigger>
                </FormControl>
                <SelectContent>
                  <SelectItem value="简单">简单</SelectItem>
                  <SelectItem value="中等">中等</SelectItem>
                  <SelectItem value="困难">困难</SelectItem>
                </SelectContent>
              </Select>
              <FormMessage />
              <Accordion type="single" collapsible>
                <AccordionItem value="difficulty">
                  <AccordionTrigger>点击此处查看题目难度定义</AccordionTrigger>
                  <AccordionContent>
                    <div className="flex flex-col">
                      <p>
                        简单：这类题目通常涉及基本的编程概念，如变量、循环、条件语句等。
                      </p>
                      <p>
                        中等：这类题目可能需要一些基本的算法知识，如排序、搜索、简单的动态规划等。
                      </p>
                      <p>
                        困难：这类题目通常涉及复杂的算法和数据结构，如高级动态规划、图论、网络流等。
                      </p>
                    </div>
                  </AccordionContent>
                </AccordionItem>
              </Accordion>
            </FormItem>
          )}
        />
      </form>
    </Form>
  );
}
